@@ -76,8 +76,6 @@ LOG = logging.getLogger(__name__)
 
 _PARTED_PRINT_RE = re.compile(r"^(\d+):([\d\.]+)MiB:"
                               r"([\d\.]+)MiB:([\d\.]+)MiB:(\w*):(.*):(.*);")
-_PARTED_TABLE_TYPE_RE = re.compile(r'^.*partition\s+table\s*:\s*(gpt|msdos)',
-                                   re.IGNORECASE | re.MULTILINE)
 
 CONFIGDRIVE_LABEL = "config-2"
 MAX_CONFIG_DRIVE_SIZE_MB = 64
@@ -185,43 +183,7 @@ def get_partition_table_type(device):
     :param device: the name of the device
     :return: dos, gpt or None
     """
-    out = utils.execute('parted', '--script', device, '--', 'print',
-                        run_as_root=True, use_standard_locale=True)[0]
-    m = _PARTED_TABLE_TYPE_RE.search(out)
-    if m:
-        return m.group(1)
-
-    LOG.warning("Unable to get partition table type for device %s", device)
-    return 'unknown'
-
-
-def _blkid(device, probe=False, fields=None):
-    args = []
-    if probe:
-        args.append('-p')
-    if fields:
-        args += sum((['-s', field] for field in fields), [])
-
-    output, err = utils.execute('blkid', device, *args,
-                                use_standard_locale=True, run_as_root=True)
-    if output.strip():
-        return output.split(': ', 1)[1]
-    else:
-        return ""
-
-
-def _lsblk(device, deps=True, fields=None):
-    args = ['--pairs', '--bytes', '--ascii']
-    if not deps:
-        args.append('--nodeps')
-    if fields:
-        args.extend(['--output', ','.join(fields)])
-    else:
-        args.append('--output-all')
-
-    output, err = utils.execute('lsblk', device, *args,
-                                use_standard_locale=True, run_as_root=True)
-    return output.strip()
+    return get_device_information(device, probe=True).get('PTTYPE')
 
 
 def get_device_information(device, probe=False, fields=None):
@@ -230,17 +192,21 @@ def get_device_information(device, probe=False, fields=None):
     Can be applied to all block devices: disks, RAID, partitions.
 
     :param device: Device name.
-    :param probe: DEPRECATED, do not use.
+    :param probe: Switch to low-level probing mode.
     :param fields: A list of fields to request (all by default).
     :return: A dictionary with requested fields as keys.
     :raises: ProcessExecutionError
     """
+    args = []
     if probe:
-        output = _blkid(device, probe=True, fields=fields)
-    else:
-        output = _lsblk(device, fields=fields, deps=False)
+        args.append('--probe')
+    if fields:
+        args += sum((['--match-tag', field] for field in fields), [])
 
-    if output:
+    output, err = utils.execute('blkid', device, *args,
+                                use_standard_locale=True, run_as_root=True)
+    if output.strip():
+        output = output.split(': ', 1)[1]
         return next(utils.parse_device_tags(output))
     else:
         return {}
@@ -289,7 +255,8 @@ def get_uefi_disk_identifier(dev):
             vals = line.split()
             partition_id = vals[0]
     try:
-        lsblk_output = _lsblk(partition_id, fields=['UUID'])
+        lsblk_output, _ = utils.execute('lsblk', '-PbioUUID', partition_id,
+                                        run_as_root=True)
         disk_identifier = lsblk_output.split("=")[1].strip()
         disk_identifier = disk_identifier.strip('"')
     except processutils.ProcessExecutionError as e:
@@ -512,26 +479,19 @@ def _retry_on_res_temp_unavailable(exc):
     retry=tenacity.retry_if_exception(_retry_on_res_temp_unavailable),
     stop=tenacity.stop_after_attempt(CONF.disk_utils.image_convert_attempts),
     reraise=True)
-def convert_image(source, dest, out_format, run_as_root=False):
+def convert_image(source, dest, out_format, run_as_root=False, cache=None,
+                  out_of_order=False):
     """Convert image to other format."""
-    cmd = ('qemu-img', 'convert', '-O', out_format, source, dest)
-    # NOTE(TheJulia): Staticly set the MALLOC_ARENA_MAX to prevent leaking
-    # and the creation of new malloc arenas which will consume the system
-    # memory. If limited to 1, qemu-img consumes ~250 MB of RAM, but when
-    # another thread tries to access a locked section of memory in use with
-    # another thread, then by default a new malloc arena is created,
-    # which essentially balloons the memory requirement of the machine.
-    # Default for qemu-img is 8 * nCPU * ~250MB (based on defaults +
-    # thread/code/process/library overhead. In other words, 64 GB. Limiting
-    # this to 3 keeps the memory utilization in happy cases below the overall
-    # threshold which is in place in case a malicious image is attempted to
-    # be passed through qemu-img.
-    env_vars = {'MALLOC_ARENA_MAX': '3'}
+    cmd = ['qemu-img', 'convert', '-O', out_format]
+    if cache is not None:
+        cmd += ['-t', cache]
+    if out_of_order:
+        cmd.append('-W')
+    cmd += [source, dest]
     try:
         utils.execute(*cmd, run_as_root=run_as_root,
                       prlimit=_qemu_img_limits(),
-                      use_standard_locale=True,
-                      env_variables=env_vars)
+                      use_standard_locale=True)
     except processutils.ProcessExecutionError as e:
         if ('Resource temporarily unavailable' in e.stderr
             or 'Cannot allocate memory' in e.stderr):
